@@ -1,4 +1,4 @@
-""" RethinkDB Model base functions.
+"""RethinkDB Model base functions.
 
 Proposes the :code:`config` function that must be called **before** any work on RethinkDB.
 If you don't call the :code:`config` function, rethink:model will use default values to
@@ -9,13 +9,13 @@ The *config* function will keep connection information inside the
 
 .. note::
 
-    this will probably change in future releases to allow usage of multiple
+    This will probably change in future releases to allow usage of multiple
     databases connections.
 """
 
 from . import db
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 
 def config(  # pylint: disable=too-many-arguments
@@ -28,9 +28,10 @@ def config(  # pylint: disable=too-many-arguments
     ssl: dict = db.SSL,
     soft_delete=db.SOFT_DELETE,
 ):
-    """Configure database connection
+    """Configure database connection.
 
-    This **must** be called **before** any Model method call !
+    This **must** be called **before** any Model method call **or** use
+    environment variables as described in :mod:`rethinkmodel.db`.
     """
     db.USER = user
     db.PASSWORD = password
